==> pipewire-docs-1%3A0.3.39-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__spa__debug.js <==
var group__spa__debug =
[
    [ "buffer.h", "debug_2buffer_8h.html", null ],
    [ "dict.h", "debug_2dict_8h.html", null ],
    [ "format.h", "debug_2format_8h.html", null ],
    [ "mem.h", "spa_2include_2spa_2debug_2mem_8h.html", null ],
    [ "node.h", "spa_2include_2spa_2debug_2node_8h.html", null ],
    [ "pod.h", "debug_2pod_8h.html", null ],
    [ "types.h", "types_8h.html", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug_buffer", "group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139", null ],
    [ "spa_debug_dict", "group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602", null ],
    [ "spa_debug_format_value", "group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe", null ],
    [ "spa_debug_format", "group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7", null ],
    [ "spa_debug_mem", "group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca", null ],
    [ "spa_debug_port_info", "group__spa__debug.html#ga26f0007da5add3060d00672939508d55", null ],
    [ "spa_debug_pod_value", "group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506", null ],
    [ "spa_debug_pod", "group__spa__debug.html#ga43da221712a4457ff34457555d39b214", null ],
    [ "spa_debug_type_find", "group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9", null ],
    [ "spa_debug_type_short_name", "group__spa__debug.html#ga894c39341a4e23d74318af04868a71df", null ],
    [ "spa_debug_type_find_name", "group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936", null ],
    [ "spa_debug_type_find_short_name", "group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a", null ],
    [ "spa_debug_type_find_type", "group__spa__debug.html#ga43407166bdc04c3822b66257581fec18", null ]
];

==> pipewire-docs-1%3A0.3.44-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__spa__debug.js <==
var group__spa__debug =
[
    [ "buffer.h", "debug_2buffer_8h.html", null ],
    [ "dict.h", "debug_2dict_8h.html", null ],
    [ "format.h", "debug_2format_8h.html", null ],
    [ "mem.h", "spa_2include_2spa_2debug_2mem_8h.html", null ],
    [ "node.h", "spa_2include_2spa_2debug_2node_8h.html", null ],
    [ "pod.h", "debug_2pod_8h.html", null ],
    [ "types.h", "types_8h.html", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug", "group__spa__debug.html#ga85dfce75df6a24fc0a29945ab03b1c86", null ],
    [ "spa_debug_buffer", "group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139", null ],
    [ "spa_debug_dict", "group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602", null ],
    [ "spa_debug_format_value", "group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe", null ],
    [ "spa_debug_format", "group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7", null ],
    [ "spa_debug_mem", "group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca", null ],
    [ "spa_debug_port_info", "group__spa__debug.html#ga26f0007da5add3060d00672939508d55", null ],
    [ "spa_debug_pod_value", "group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506", null ],
    [ "spa_debug_pod", "group__spa__debug.html#ga43da221712a4457ff34457555d39b214", null ],
    [ "spa_debug_type_find", "group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9", null ],
    [ "spa_debug_type_short_name", "group__spa__debug.html#ga894c39341a4e23d74318af04868a71df", null ],
    [ "spa_debug_type_find_name", "group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936", null ],
    [ "spa_debug_type_find_short_name", "group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a", null ],
    [ "spa_debug_type_find_type", "group__spa__debug.html#ga43407166bdc04c3822b66257581fec18", null ],
    [ "spa_debug_type_find_short", "group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954", null ],
    [ "spa_debug_type_find_type_short", "group__spa__debug.html#gac6f960544afa686154bfebae8c42406b", null ]
];
